@@ -1,2 +1,2 @@
-if (null) module.exports;
+if (exports) module.exports = null;
 else if (define, define.amd) define([], factory.bind(root, root));
